@@ -151,7 +151,7 @@ bool MergeUtil::isSame(const QVariant& lhs, const QVariant& rhs)
         return isSameFlight(lhsFlight, rhsFlight);
     }
 
-    // train: booking ref, train number and depature day match
+    // train: booking ref, train number and departure day match
     if (JsonLd::isA<TrainReservation>(lhs)) {
         const auto lhsRes = lhs.value<TrainReservation>();
         const auto rhsRes = rhs.value<TrainReservation>();
@@ -383,10 +383,21 @@ static bool isSameTrainTrip(const TrainTrip &lhs, const TrainTrip &rhs)
         qCDebug(CompareLog) << "unbound trip" << lhs.departureStation().name() << rhs.departureStation().name() << lhs.arrivalStation().name() << rhs.arrivalStation().name();
         return LocationUtil::isSameLocation(lhs.departureStation(), rhs.departureStation(), LocationUtil::Exact)
             && LocationUtil::isSameLocation(lhs.arrivalStation(), rhs.arrivalStation(), LocationUtil::Exact);
-    } else if (!equalAndPresent(lhs.departureTime(), rhs.departureTime()) || conflictIfPresent(lhs.arrivalTime(), rhs.arrivalTime())) {
+    } else if (!equalAndPresent(lhs.departureTime(), rhs.departureTime())) {
         return false;
     }
 
+    // arrival times (when present) should either match exactly, or be almost the same at a matching arrival location
+    // (tickets even for the same connection booked on the same day sometimes have slight variation in the arrival time...)
+    if (conflictIfPresent(lhs.arrivalTime(), rhs.arrivalTime())) {
+        if (std::abs(lhs.arrivalTime().secsTo(rhs.arrivalTime())) > 180) {
+            return false;
+        }
+        if (!LocationUtil::isSameLocation(lhs.arrivalStation(), rhs.arrivalStation(), LocationUtil::Exact)) {
+            return false;
+        }
+    }
+
     // if we don't have train numbers, also fall back to the less robust location comparison
     if (lhs.trainNumber().isEmpty() || rhs.trainNumber().isEmpty()) {
         qCDebug(CompareLog) << "missing train number" << lhs.trainNumber() << rhs.trainNumber();
